@@ -25,6 +25,7 @@ PARAMS_KEYS = (
     'opt_rota',
     'opt_dbug',
     'opt_prnt',
+    'opt_dpth',
     'dir_remo'
 )
 
@@ -55,6 +56,7 @@ PARAMS_VALS = (
     False,
     False,
     True,
+    True,
     False
 )
 
@@ -84,6 +86,7 @@ PARAMS_TYPE = (
     'bool',
     'bool',
     'bool',
+    'bool',
     'bool'
 )
 
@@ -113,6 +116,7 @@ PARAMS_NAME = (
     'Rotation of light field',
     'Debug option',
     'Status print option',
+    'Depth map computation',
     'Remove output folder'
 )
 
