@@ -30,6 +30,7 @@ from plenopticam.lfp_extractor.lfp_contrast import LfpContrast
 from plenopticam.lfp_extractor.lfp_outliers import LfpOutliers
 from plenopticam.lfp_extractor.lfp_color_eq import LfpColorEqualizer
 from plenopticam.lfp_extractor.hex_corrector import HexCorrector
+from plenopticam.lfp_extractor.lfp_depth import LfpDepth
 
 import pickle
 import os
@@ -47,6 +48,7 @@ class LfpExtractor(object):
         # variables for viewpoint arrays
         self.vp_img_arr = []        # gamma corrected
         self.vp_img_linear = []     # linear gamma (for further processing)
+        self.depth_map = None
 
     def main(self):
 
@@ -105,6 +107,13 @@ class LfpExtractor(object):
             obj.write_viewpoint_data()
             del obj
 
+        # compute and write depth data from epipolar analysis
+        if self.cfg.params[self.cfg.opt_dpth]:
+            obj = LfpDepth(vp_img_arr=self.vp_img_arr, cfg=self.cfg, sta=self.sta)
+            obj.main()
+            self.depth_map = obj.depth_map
+            del obj
+
         return True
 
     def load_pickle_file(self):
